@@ -1,28 +1,5 @@
 # For complete documentation of this file, please see Geany's main documentation
-[styling]
-# foreground;background;bold;italic
-default=default
-comment=comment
-commentline=comment
-commentdoc=commentdoc
-number=number
-word=keyword
-word2=keyword2
-string=string
-character=string
-uuid=extra
-preprocessor=preprocessor
-operator=operator
-identifier=default
-stringeol=stringeol
-# @"verbatim"
-verbatim=extra
-# (/regex/)
-regex=extra
-commentlinedoc=commentdoc,bold
-commentdockeyword=commentdoc,bold,italic
-commentdockeyworderror=commentdoc
-globalclass=type
+[styling=C]
 
 [keywords]
 # all items must be in one line
@@ -33,6 +10,7 @@ docComment=attention author brief bug class code date def enum example exception
 
 [lexer_properties]
 styling.within.preprocessor=1
+lexer.cpp.track.preprocessor=0
 preprocessor.symbol.$(file.patterns.cpp)=#
 preprocessor.start.$(file.patterns.cpp)=if
 preprocessor.middle.$(file.patterns.cpp)=else elif
@@ -47,12 +25,11 @@ extension=cs
 # the following characters are these which a "word" can contains, see documentation
 #wordchars=_abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789
 
-# if only single comment char is supported like # in this file, leave comment_close blank
-comment_open=//
-comment_close=
-# this is an alternative way, so multiline comments are used
-#comment_open=/*
-#comment_close=*/
+# single comments, like # in this file
+comment_single=//
+# multiline comments
+comment_open=/*
+comment_close=*/
 
 # set to false if a comment character/string should start at column 0 of a line, true uses any
 # indentation of the line, e.g. setting to true causes the following on pressing CTRL+d
@@ -65,6 +42,11 @@ comment_use_indent=true
 # context action command (please see Geany's main documentation for details)
 context_action_cmd=
 
+[indentation]
+#width=4
+# 0 is spaces, 1 is tabs, 2 is tab & spaces
+#type=1
+
 [build_settings]
 # %f will be replaced by the complete filename
 # %e will be replaced by the filename without extension
